
#ifndef PIMCOMMONAKONADI_EXPORT_H
#define PIMCOMMONAKONADI_EXPORT_H

#ifdef PIMCOMMONAKONADI_STATIC_DEFINE
#  define PIMCOMMONAKONADI_EXPORT
#  define PIMCOMMONAKONADI_NO_EXPORT
#else
#  ifndef PIMCOMMONAKONADI_EXPORT
#    ifdef KPim6PimCommonAkonadi_EXPORTS
        /* We are building this library */
#      define PIMCOMMONAKONADI_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define PIMCOMMONAKONADI_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef PIMCOMMONAKONADI_NO_EXPORT
#    define PIMCOMMONAKONADI_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef PIMCOMMONAKONADI_DECL_DEPRECATED
#  define PIMCOMMONAKONADI_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef PIMCOMMONAKONADI_DECL_DEPRECATED_EXPORT
#  define PIMCOMMONAKONADI_DECL_DEPRECATED_EXPORT PIMCOMMONAKONADI_EXPORT PIMCOMMONAKONADI_DECL_DEPRECATED
#endif

#ifndef PIMCOMMONAKONADI_DECL_DEPRECATED_NO_EXPORT
#  define PIMCOMMONAKONADI_DECL_DEPRECATED_NO_EXPORT PIMCOMMONAKONADI_NO_EXPORT PIMCOMMONAKONADI_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef PIMCOMMONAKONADI_NO_DEPRECATED
#    define PIMCOMMONAKONADI_NO_DEPRECATED
#  endif
#endif
#include <pimcommonakonadi_version.h>

#define PIMCOMMONAKONADI_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(PIMCOMMONAKONADI_NO_DEPRECATED)
#  undef PIMCOMMONAKONADI_DEPRECATED
#  define PIMCOMMONAKONADI_DEPRECATED_EXPORT PIMCOMMONAKONADI_EXPORT
#  define PIMCOMMONAKONADI_DEPRECATED_NO_EXPORT PIMCOMMONAKONADI_NO_EXPORT
#elif defined(PIMCOMMONAKONADI_NO_DEPRECATED_WARNINGS)
#  define PIMCOMMONAKONADI_DEPRECATED
#  define PIMCOMMONAKONADI_DEPRECATED_EXPORT PIMCOMMONAKONADI_EXPORT
#  define PIMCOMMONAKONADI_DEPRECATED_NO_EXPORT PIMCOMMONAKONADI_NO_EXPORT
#else
#  define PIMCOMMONAKONADI_DEPRECATED PIMCOMMONAKONADI_DECL_DEPRECATED
#  define PIMCOMMONAKONADI_DEPRECATED_EXPORT PIMCOMMONAKONADI_DECL_DEPRECATED_EXPORT
#  define PIMCOMMONAKONADI_DEPRECATED_NO_EXPORT PIMCOMMONAKONADI_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define PIMCOMMONAKONADI_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define PIMCOMMONAKONADI_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef PIMCOMMONAKONADI_NO_DEPRECATED
#  define PIMCOMMONAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT PIMCOMMONAKONADI_VERSION
#endif
#ifdef PIMCOMMONAKONADI_NO_DEPRECATED_WARNINGS
#  define PIMCOMMONAKONADI_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef PIMCOMMONAKONADI_DEPRECATED_WARNINGS_SINCE
#  ifdef PIMCOMMONAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define PIMCOMMONAKONADI_DEPRECATED_WARNINGS_SINCE PIMCOMMONAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define PIMCOMMONAKONADI_DEPRECATED_WARNINGS_SINCE PIMCOMMONAKONADI_VERSION
#  endif
#endif

#ifndef PIMCOMMONAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define PIMCOMMONAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef PIMCOMMONAKONADI_DEPRECATED
#  define PIMCOMMONAKONADI_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > PIMCOMMONAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define PIMCOMMONAKONADI_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* PIMCOMMONAKONADI_EXPORT_H */
