
#ifndef PIMCOMMONACTIVITIES_EXPORT_H
#define PIMCOMMONACTIVITIES_EXPORT_H

#ifdef PIMCOMMONACTIVITIES_STATIC_DEFINE
#  define PIMCOMMONACTIVITIES_EXPORT
#  define PIMCOMMONACTIVITIES_NO_EXPORT
#else
#  ifndef PIMCOMMONACTIVITIES_EXPORT
#    ifdef KPim6PimCommonActivities_EXPORTS
        /* We are building this library */
#      define PIMCOMMONACTIVITIES_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define PIMCOMMONACTIVITIES_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef PIMCOMMONACTIVITIES_NO_EXPORT
#    define PIMCOMMONACTIVITIES_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef PIMCOMMONACTIVITIES_DECL_DEPRECATED
#  define PIMCOMMONACTIVITIES_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef PIMCOMMONACTIVITIES_DECL_DEPRECATED_EXPORT
#  define PIMCOMMONACTIVITIES_DECL_DEPRECATED_EXPORT PIMCOMMONACTIVITIES_EXPORT PIMCOMMONACTIVITIES_DECL_DEPRECATED
#endif

#ifndef PIMCOMMONACTIVITIES_DECL_DEPRECATED_NO_EXPORT
#  define PIMCOMMONACTIVITIES_DECL_DEPRECATED_NO_EXPORT PIMCOMMONACTIVITIES_NO_EXPORT PIMCOMMONACTIVITIES_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef PIMCOMMONACTIVITIES_NO_DEPRECATED
#    define PIMCOMMONACTIVITIES_NO_DEPRECATED
#  endif
#endif
#include <pimcommonactivities_version.h>

#define PIMCOMMONACTIVITIES_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(PIMCOMMONACTIVITIES_NO_DEPRECATED)
#  undef PIMCOMMONACTIVITIES_DEPRECATED
#  define PIMCOMMONACTIVITIES_DEPRECATED_EXPORT PIMCOMMONACTIVITIES_EXPORT
#  define PIMCOMMONACTIVITIES_DEPRECATED_NO_EXPORT PIMCOMMONACTIVITIES_NO_EXPORT
#elif defined(PIMCOMMONACTIVITIES_NO_DEPRECATED_WARNINGS)
#  define PIMCOMMONACTIVITIES_DEPRECATED
#  define PIMCOMMONACTIVITIES_DEPRECATED_EXPORT PIMCOMMONACTIVITIES_EXPORT
#  define PIMCOMMONACTIVITIES_DEPRECATED_NO_EXPORT PIMCOMMONACTIVITIES_NO_EXPORT
#else
#  define PIMCOMMONACTIVITIES_DEPRECATED PIMCOMMONACTIVITIES_DECL_DEPRECATED
#  define PIMCOMMONACTIVITIES_DEPRECATED_EXPORT PIMCOMMONACTIVITIES_DECL_DEPRECATED_EXPORT
#  define PIMCOMMONACTIVITIES_DEPRECATED_NO_EXPORT PIMCOMMONACTIVITIES_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define PIMCOMMONACTIVITIES_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define PIMCOMMONACTIVITIES_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef PIMCOMMONACTIVITIES_NO_DEPRECATED
#  define PIMCOMMONACTIVITIES_DISABLE_DEPRECATED_BEFORE_AND_AT PIMCOMMONACTIVITIES_VERSION
#endif
#ifdef PIMCOMMONACTIVITIES_NO_DEPRECATED_WARNINGS
#  define PIMCOMMONACTIVITIES_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef PIMCOMMONACTIVITIES_DEPRECATED_WARNINGS_SINCE
#  ifdef PIMCOMMONACTIVITIES_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define PIMCOMMONACTIVITIES_DEPRECATED_WARNINGS_SINCE PIMCOMMONACTIVITIES_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define PIMCOMMONACTIVITIES_DEPRECATED_WARNINGS_SINCE PIMCOMMONACTIVITIES_VERSION
#  endif
#endif

#ifndef PIMCOMMONACTIVITIES_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define PIMCOMMONACTIVITIES_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef PIMCOMMONACTIVITIES_DEPRECATED
#  define PIMCOMMONACTIVITIES_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > PIMCOMMONACTIVITIES_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define PIMCOMMONACTIVITIES_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* PIMCOMMONACTIVITIES_EXPORT_H */
